# AUTHOR.md
This file lists the authors, maintainers, and contributors for the
[applyaf][] project.

## Authors
- Matthew Rankin

## Maintainers
- None at this time.

## Contributors
- None at this time.

[applyaf]: https://github.com/questrail/applyaf
